# Easyplayer
Easyplayer is a python library that encapsulates the complex API of pygame2 to help users build games faster.

<h1 style="color:#FF0000;">Dev Version, instable!</h1>

# Install
Use `pip`:
```shell
pip install easyplayer
```
Use `git`:
```shell
git clone https://github.com/stripepython/easyplayer.git
cd easyplayer
pip install -r requirements.txt  
# If the installation fails, it can be installed manually.
python setup.py install
```
